;**********************************************************************
;   This file is a basic code template for assembly code generation   *
;   on the PIC16F627A. This file contains the basic code              *
;   building blocks to build upon.                                    *
;                                                                     *
;   Refer to the MPASM User's Guide for additional information on     *
;   features of the assembler (Document DS33014).                     *
;                                                                     *
;   Refer to the respective PIC data sheet for additional             *
;   information on the instruction set.                               *
;                                                                     *
;**********************************************************************
;                                                                     *
;    Filename:	    Earrings.asm                                           *
;    Date:        September 26, 2014                                                   *
;    File Version:                                                    *
;                                                                     *
;    Author:         Ron Newton                                                 *
;    Company:                                                         *
;     REV	1  10/4/2014  ELIMINATED DELAYS                                                                *
;                                                                     *
;**********************************************************************
;                                                                     *
;    Files Required: P16F627A.INC                                     *
;                                                                     *
;**********************************************************************
;                                                                     *
;    Notes:                                                           *
;Pin 1		RA2		NC
;Pin 2		RA3		NC
;Pin 3		RA4		NC
;Pin 4		RA5 MCLR	NC
;Pin 5		VSS		NEGATIVE
;Pin 6		RB0		LED RESISTOR
;Pin 7		RB1		LED RESISTOR
;Pin 8		RB2		LED RESISTOR
;Pin 9		RB3		LED RESISTOR
;Pin 10		RB4		LED RESISTOR
;Pin 11		RB5		LED RESISTOR
;Pin 12		RB6		LED RESISTOR
;Pin 13		RB7		LED RESISTOR
;Pin 14		VCC		3 VOLTS +
;Pin 15		RA6		NC
;Pin 16		RA7		NC
;Pin 17		RA0		COLUMN 1 RESISTOR
;Pin 18     RA1     COLUMN 2 RESISTOR                                                          *
;**********************************************************************

	list      p=16f627A           ; list directive to define processor
	#include <p16F627A.inc>       ; processor specific variable definitions

	errorlevel  -302              ; suppress message 302 from list file

	__CONFIG   _CP_OFF &  _LVP_OFF & _BOREN_OFF & _MCLRE_OFF & _WDT_ON & _PWRTE_OFF & _INTOSC_OSC_NOCLKOUT 

; '__CONFIG' directive is used to embed configuration word within .asm file.
; The lables following the directive are located in the respective .inc file.
; See data sheet for additional information on configuration word settings.

#DEFINE		C1		PORTA,0
#DEFINE		C2		PORTA,1
	CBLOCK	0X20
COUNT		;COUNTING REGISTER
COUNT1		;COUNTING REGISTER
COUNT2		;COUNTING REGISTER
COUNT3		;COUNTING REGISTER
TIMER		;COUNTING REGISTER
TIMER1		;COUNTING REGISTER
TIMER2		;COUNTING REGISTER
TIMER3		;COUNTING REGISTER
TIMER4		;COUNTING REGISTER
RAND
	ENDC




;**********************************************************************
	ORG     0x000             ; processor reset vector
	goto    main              ; go to beginning of program



main
		CLRF		PORTA		;CLEARPORTA
		CLRF		PORTB		;CLEAR PORTB
		BANKSEL		TRISA		;CHANGE BANKS
		CLRF		TRISA		;CLEAR TRISA	MAKE ALL OUTPUTS
		CLRF		TRISB		;CLEAR TRISB	MAK ALL OUTPUTS
		BANKSEL		PORTA		;CHANGE BANKS
		MOVLW		0X07		;LOAD 7
		MOVWF		CMCON		;MAKE ALL PORTA DIGITAL
		BANKSEL		PCON		;CHANGE BANKS
		MOVLW		B'00001000'	;MOVE 8 INTO PCON
		MOVWF		PCON		;MAKE 4 mHZ
		MOVLW		B'00001111'	;LOAD 15
		MOVWF		OPTION_REG	;WATCH DOG TIMER MAXIMUM
		BANKSEL		PORTA
		
				
;**************************TESTING AREA****************
TEST


	
;*******************************************************

START	CALL		RANDOM			;CALLING RANDOM
		CALL		DECISECOND50	;DELAY
		CALL		BLINK			;CALLING BLINK
;		CALL		DECISECOND50	;DELAY
		CALL		BLINK			; CALL BLINK AGIN
;		CALL		DECISECOND50	;DELAY
		CALL		UP_DOWN			;CALL UP_DOWN
		CALL		BLINK			;CALL BLINK
;		CALL		DECISECOND50	;DELAY
		CALL		UP_DOWN
;		CALL		DECISECOND50	;DELAY
		CALL		COLORS
;		CALL		DECISECOND50	;DELAY
		CALL		BLINK
;		CALL		DECISECOND50	;DELAY		
		CALL		COLORS
		GOTO		START			;DO AGAIN 

RANDOM	CALL		RANDOM1
		MOVF		RAND,0
		MOVWF		PORTB
		MOVWF		PORTA
		DECFSZ		COUNT,1
		GOTO		RANDOM
		DECFSZ		COUNT3,1
		GOTO		RANDOM
		RETURN		

RANDOM1
		RLF			RAND,W
		RLF			RAND,W
		BTFSC		RAND,4
		XORLW		1
		BTFSC		RAND,5
		XORLW		1
		BTFSC		RAND,3
		XORLW		1
		MOVWF		RAND
		RETURN
		
BLINK	BSF			C1				;TURN ON C1
		BSF			C2				;TURN ON C2
		MOVLW		.255			;TURN ON ALL PORTS B
		MOVWF		PORTB			
T1		CALL		FLASH2			;CALL FLASH
		BCF			C1				;TURN OFF C1
		BCF			C2				;TURN OFF C3
		RETURN
		
UP_DOWN	BCF			C1			
		BSF			C2
		MOVLW		.1
		MOVWF		PORTB
U1		CALL		DECISECOND
		RLF			PORTB,1			;ROTATE LEFT PORT B ONE BIT
		BTFSS		PORTB,0
		GOTO		U1		
U2		BSF			C1
		BCF			C2
		CALL		DECISECOND
		RLF			PORTB,1
		BTFSS		PORTB,0
		GOTO		U2
		BCF			C1
		BCF			C2
DOWN_UP BCF			C1
		BSF			C2
		MOVLW		.1
		MOVWF		PORTB
DU1		CALL		DECISECOND
		RRF			PORTB,1
		BTFSS		PORTB,0
		GOTO		DU1
		BSF			C1
		BCF			C2
		MOVLW		.128
		MOVWF		PORTB
DU2		CALL		DECISECOND
		RRF			PORTB,1
		BTFSS		PORTB,0
		GOTO		DU2
		CALL		SECOND
		BCF			C1
		BCF			C2
		RETURN
		
COLORS	BSF			C1				;GREEN
		BSF			C2
		MOVLW		.1
		MOVWF		PORTB
		CALL		DECISECOND
		MOVLW		.16
		MOVWF		PORTB		
		CALL		DECISECOND

		

		MOVLW		.2					;YELLOW
		MOVWF		PORTB
		CALL		DECISECOND
		MOVLW		.32
		MOVWF		PORTB
		CALL		DECISECOND
		

		MOVLW		.4					;RED
		MOVWF		PORTB		
		CALL		DECISECOND
		MOVLW		.64
		MOVWF		PORTB
		CALL		DECISECOND
	
		
		
		MOVLW		.8					;BLUE
		MOVWF		PORTB
		CALL		DECISECOND
		MOVLW		.128
		MOVWF		PORTB
		CALL		DECISECOND

		BCF			C1
		BCF			C2			
		RETURN

COLUMN	BSF			C1
		BCF			C2
		CALL		FLASH
		BCF			C1
		CALL		DECISECOND
		BSF			C2
		CALL		FLASH
		BCF			C2
		CALL		DECISECOND
		BCF			C1
		BCF			C2
		RETURN
		
FLASH1	MOVLW		.175
		MOVWF		TIMER
		MOVLW		.200
		MOVWF		TIMER1
F1		CLRWDT
		DECFSZ		TIMER,1
		GOTO		F1
		MOVLW		.175
		MOVWF		TIMER
		DECFSZ		TIMER1,1
		GOTO		F1
		RETURN

FLASH	MOVLW		.175
		MOVWF		TIMER
		MOVLW		.10
		MOVWF		TIMER1
F2		CLRWDT
		DECFSZ		TIMER,1
		GOTO		F2
		MOVLW		.175
		MOVWF		TIMER
		DECFSZ		TIMER1,1
		GOTO		F2

		RETURN
		
FLASH2	MOVLW		.100
		MOVWF		TIMER1
F3		CLRWDT
		DECFSZ		TIMER,1
		GOTO		F3
		DECFSZ		TIMER1,1
		GOTO		F3
		RETURN		

DECISECOND	
		MOVLW		.32
		MOVWF		TIMER
		MOVLW		.10
		MOVWF		TIMER1								
		MOVWF		TIMER2
D1		CLRWDT
		DECFSZ		TIMER,1
		GOTO		D1
		MOVLW		.32
		MOVWF		TIMER
		DECFSZ		TIMER1,1
		GOTO		D1
		MOVWF		.10
		MOVWF		TIMER1
		DECFSZ		TIMER2,1
		GOTO		D1

		RETURN
		
DECISECOND50	
		MOVLW		.24
		MOVWF		TIMER
		MOVLW		.100
		MOVWF		TIMER1
		MOVLW		.5	
		MOVWF		TIMER2							

D51		CLRWDT
		DECFSZ		TIMER,1
		GOTO		D51
		MOVLW		.24
		MOVWF		TIMER
		DECFSZ		TIMER1,1
		GOTO		D51
		MOVLW		.10
		MOVWF		TIMER1
		DECFSZ		TIMER2,1
		GOTO		D51
		MOVLW		.10
		MOVWF		TIMER2
		DECFSZ		TIMER3,1
		GOTO		D51
		RETURN		

SECOND	MOVLW		.24
		MOVWF		TIMER
		MOVLW		.10
		MOVWF		TIMER1								
		MOVWF		TIMER2
		MOVWF		TIMER3
		MOVWF		TIMER4
S1		CLRWDT
		DECFSZ		TIMER,1
		GOTO		S1
		MOVLW		.24
		MOVWF		TIMER
		DECFSZ		TIMER1,1
		GOTO		S1
		MOVLW		.10
		MOVWF		TIMER1
		DECFSZ		TIMER2,1
		GOTO		S1
		MOVLW		.10
		MOVWF		TIMER2
		DECFSZ		TIMER3,1
		GOTO		S1
		MOVLW		.10
		MOVWF		TIMER3
		DECFSZ		TIMER4,1
		GOTO		S1
			RETURN		
		
	END                       ; directive 'end of program'

